import numpy as np
import scipy.stats as ss
import scipy.optimize as so

class U_cum_bin():
    def __init__(self, N, k, a):
        self.N = N
        self.k = k
        self.a = a
        
    def f(self, p):
        return ss.binom.cdf(self.k, self.N, p) - self.a/2
    
def U_boundary(N, k, a):
    if k == N:
        v = 1.0
    else:
        func = U_cum_bin(N, k, a).f
        v = so.bisect(func, 0, 1)
    return v

class L_cum_bin():
    def __init__(self, N, k, a):
        self.N = N
        self.k = k
        self.a = a
        
    def f(self, p):
        return 1.0 - ss.binom.cdf(self.k - 1, self.N, p) - self.a/2
    
def L_boundary(N, k, a):
    if k == 0:
        v = 0.0
    else:
        func = L_cum_bin(N, k, a).f
        v = so.bisect(func, 0, 1)
    return v

N = int(input('N = '))
k = int(input('k = '))
a = float(input('a = '))
Lb = L_boundary(N, k, a)
Ub = U_boundary(N, k, a)
print(f'{(1-a)*100}%信頼区間 = [{Lb:.5}, {Ub:.5}]')
